{% extends 'forum/post_list.html' %}
{% load crispy_forms_tags %}

{% block title %}
    Update Topic
{% endblock title %}


{% load django_bootstrap_breadcrumbs %}

{% block breadcrumbs %}
    {{ block.super }}
    {% breadcrumb "Update" "forum:topic_update" %}

{% endblock breadcrumbs %}



{% block content %}
    {% render_breadcrumbs %}

    <form action="" method="post">
        {% csrf_token %}
        {{ form | crispy }}
        <input type="submit" class="btn btn-primary" value="Update"/>
    </form>

{% endblock %}