{% extends 'forum/index.html' %}
{% block title %}
    New Topic
{% endblock title %}

{% load django_bootstrap_breadcrumbs %}

{% block breadcrumbs %}
    {{ block.super }}
    {% breadcrumb "New Topic" "forum:new_topic" %}

{% endblock breadcrumbs %}


{% block content %}

    {% render_breadcrumbs %}

    {% load crispy_forms_tags %}


    <form action="" method="post">
        {% csrf_token %}
        {{ form | crispy }}
        <input type="submit" class="btn btn-success" value="Create"/>
    </form>

{% endblock content %}
