{% extends 'forum/post_list.html' %}

{% block title %}
    New Post
{% endblock title %}

{% load django_bootstrap_breadcrumbs %}

{% block breadcrumbs %}
    {{ block.super }}
    {% breadcrumb "New Post" "forum:new_post" %}
{% endblock breadcrumbs %}



{% block content %}
    {% render_breadcrumbs %}

    {% load crispy_forms_tags %}
    <form action="{% url 'forum:new_post' topic.slug %}" method="POST">
        {% csrf_token %}
        {{ form|crispy }}
        <div class="form-actions">
            <input type="submit" name="submit" value="Post" class="btn btn-primary" id="submit-save">
        </div>
    </form>
{% endblock content %}